chapter10

package module
v2.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package chapter10 contains the solution to the exercises in chapter 10 of Learning Go, 2nd edition.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Add

func Add[T Number](a, b T) T

Adds two numeric values and returns their sum as defined in mathisfun.

Types

type Number

type Number interface {
	constraints.Integer | constraints.Float
}

Jump to